[llvm-commits] CVS: llvm/include/llvm/Target/TargetOptions.h
Evan Cheng
evan.cheng at apple.com
Tue May 23 11:19:00 PDT 2006
Changes in directory llvm/include/llvm/Target:
TargetOptions.h updated: 1.9 -> 1.10
---
Log message:
-enable-unsafe-fp-math implies -enable-finite-only-fp-math
---
Diffs of the changes: (+6 -5)
TargetOptions.h | 11 ++++++-----
1 files changed, 6 insertions(+), 5 deletions(-)
Index: llvm/include/llvm/Target/TargetOptions.h
diff -u llvm/include/llvm/Target/TargetOptions.h:1.9 llvm/include/llvm/Target/TargetOptions.h:1.10
--- llvm/include/llvm/Target/TargetOptions.h:1.9 Tue May 23 01:39:12 2006
+++ llvm/include/llvm/Target/TargetOptions.h Tue May 23 13:18:46 2006
@@ -39,14 +39,15 @@
/// this flag is off (the default), the code generator is not allowed to
/// produce results that are "less precise" than IEEE allows. This includes
/// use of X86 instructions like FSIN and FCOS instead of libcalls.
+ /// UnsafeFPMath implies FiniteOnlyFPMath.
extern bool UnsafeFPMath;
/// FiniteOnlyFPMath - This is enabled when the -enable-finite-only-fp-math
/// flag is specified on the command line. When this flag is off (default),
/// the code generator is not allowed to assume that FP arithmetic arguments
- /// and results are never NaNs or +-Infs. This includes ignoring parity flag
- /// (PF) when checking for FP equality.
- extern bool FiniteOnlyFPMath;
+ /// and results are never NaNs or +-Infs.
+ extern bool FiniteOnlyFPMathOption;
+ extern bool FiniteOnlyFPMath();
} // End llvm namespace
#endif
More information about the llvm-commits
@@ -39,14 +39,15 @@
extern bool UnsafeFPMath;
- /// FiniteOnlyFPMath - This is enabled when the -enable-finite-only-fp-math
- /// flag is specified on the command line. When this flag is off (default),
+ /// FiniteOnlyFPMath - This returns true when the -enable-finite-only-fp-math
+ /// option is specified on the command line. If this returns false (default),
/// the code generator is not allowed to assume that FP arithmetic arguments
mailing list